@@ -1,22 +1,6 @@
-# color_log_formatter.py
-#
-# Copyright 2023 Geoffrey Coulaud
-# Copyright 2023-2024 kramo
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 # SPDX-License-Identifier: GPL-3.0-or-later
+# SPDX-FileCopyrightText: Copyright 2023 Geoffrey Coulaud
+# SPDX-FileCopyrightText: Copyright 2024-2025 kramo
 
 from logging import Formatter, LogRecord
 
@@ -31,6 +15,7 @@ class ColorLogFormatter(Formatter):
     YELLOW = "\033[33m"
 
     def format(self, record: LogRecord) -> str:
+        """Format log messages."""
         super_format = super().format(record)
         match record.levelname:
             case "CRITICAL":
